from reamber.base.HoldObj import HoldObj
from dataclasses import dataclass


@dataclass
class SMRollObj(HoldObj):
    pass
